@@ -2,8 +2,8 @@ package middlewares
 
 import (
 	"github.com/sirupsen/logrus"
-	"github.com/snyk/driftctl/pkg/resource"
-	"github.com/snyk/driftctl/pkg/resource/aws"
+	"github.com/snyk/driftctl/enumeration/resource"
+	"github.com/snyk/driftctl/enumeration/resource/aws"
 )
 
 // AwsRDSClusterInstanceExpander search for cluster instances from state to import corresponding remote db instances.
