@@ -1,6 +1,6 @@
 package github
 
-import "github.com/snyk/driftctl/pkg/resource"
+import "github.com/snyk/driftctl/enumeration/resource"
 
 func InitResourcesMetadata(resourceSchemaRepository resource.SchemaRepositoryInterface) {
 	initGithubBranchProtectionMetaData(resourceSchemaRepository)
