@@ -4,10 +4,11 @@ import (
 	"strings"
 	"testing"
 
+	"github.com/snyk/driftctl/enumeration/terraform"
+
 	"github.com/aws/aws-sdk-go/aws/awsutil"
 	"github.com/r3labs/diff/v2"
-	"github.com/snyk/driftctl/pkg/resource"
-	"github.com/snyk/driftctl/pkg/terraform"
+	"github.com/snyk/driftctl/enumeration/resource"
 	"github.com/snyk/driftctl/test/goldenfile"
 	"github.com/zclconf/go-cty/cty"
 	"github.com/zclconf/go-cty/cty/gocty"
